@@ -3,9 +3,10 @@ import tempfile
 
 class TemporaryDirectory(tempfile.TemporaryDirectory):
     """A TemporaryDirectory similar to tempfile but which can be detached if
-       `keep` is True i.e. the directory isn't cleaned up on object garbage
-        collection
+    `keep` is True i.e. the directory isn't cleaned up on object garbage
+     collection
     """
+
     def __init__(self, *args, keep=False, **kwargs):
         super(TemporaryDirectory, self).__init__(*args, **kwargs)
 
@@ -17,7 +18,8 @@ class TemporaryDirectory(tempfile.TemporaryDirectory):
         if not self.keep or exc is None:
             self.cleanup()
         else:
-            _warnings.warn(f"Not cleaning up {self.name} due to exception. "
-                           f"Set `keep=False` to force cleanup",
-                           ResourceWarning)
-
+            _warnings.warn(
+                f"Not cleaning up {self.name} due to exception. "
+                f"Set `keep=False` to force cleanup",
+                ResourceWarning,
+            )
